==> nextcloud-app-mail-5.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/es_AR.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Importante",
    "Work" : "Trabajo",
    "Personal" : "Personal",
    "Later" : "Después",
    "Mail" : "Correo",
    "Connecting" : "Conectando",
    "Save" : "Guardar",
    "Connect" : "Conectar",
    "Password required" : "Se requiere contraseña",
    "Name" : "Nombre",
    "Mail address" : "Dirección de correo",
    "Password" : "Contraseña",
    "IMAP Host" : "Servidor IMAP",
    "None" : "Ninguno",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Puerto IMAP",
    "IMAP User" : "Usuario IMAP",
    "IMAP Password" : "Contraseña IMAP",
    "SMTP Host" : "Servior SMTP",
    "SMTP Port" : "Puerto SMTP",
    "SMTP User" : "Usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Aliases" : "Aliases",
    "Signature" : "Firma",
    "Go back" : "Regresar",
    "Change name" : "Cambiar nombre",
    "Cancel" : "Cancelar",
    "Add mail account" : "Agregar cuenta de correo",
    "General" : "General",
    "Sorting" : "Orden",
    "Register" : "Registrar",
    "Keyboard shortcuts" : "Atajos de teclado",
    "Compose new message" : "Redactar nuevo mensaje",
    "Newer message" : "Mensaje mas nuevo",
    "Older message" : "Mensaje anterior",
    "Archive" : "Archivar",
    "Delete" : "Borrar",
    "Search" : "Buscar",
    "Send" : "Enviar",
    "Refresh" : "Recargar",
    "Select account" : "Seleccione la cuenta",
    "Subject" : "Asunto",
    "Add attachment from Files" : "Agregar adjunto desde Archivos",
    "Choose" : "Elige",
    "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
    "Confirm" : "Confirmar",
    "Favorite" : "Favorito",
    "Read" : "Leer",
    "Edit tags" : "Editar etiquetas",
    "Back" : "Atrás",
    "All day" : "Todo el día",
    "Description" : "Descripción",
    "Create" : "Crear",
    "Select" : "Seleccionar",
    "Comment" : "Comentario",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "More options" : "Más opciones",
    "Remove" : "Borrar",
    "email" : "correo electrónico",
    "Other" : "Otro",
    "Forward" : "Reenviar",
    "Translate" : "Traducir",
    "Unnamed" : "Sin nombre",
    "Choose a folder to store the attachment in" : "Selecccione la carpeta en la cual almacenar el adjunto",
    "Import into calendar" : "Importar al calendario",
    "Download attachment" : "Descargar adjunto",
    "Save to Files" : "Guardar a Archivos",
    "Save all to Files" : "Guardar todos a Archivos",
    "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger su privacidad. ",
    "Move" : "Mover",
    "Remove account" : "Eliminar cuenta",
    "Quota" : "Cuota",
    "Saving" : "Guardando",
    "Mark all as read" : "Marcar todos como leídos",
    "Rename" : "Renombrar",
    "Clear cache" : "Limpiar caché",
    "New message" : "Mensaje nuevo",
    "Reply" : "Responder",
    "Retry" : "Reintentar",
    "Sending …" : "Enviando ...",
    "Message" : "Mensaje",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Add" : "Añadir",
    "Clear" : "Borrar",
    "Close" : "Cerrar",
    "Date" : "Fecha",
    "Tags" : "Etiquetas",
    "Custom" : "Personalizado",
    "Tag already exists" : "La etiqueta ya existe",
    "Add tag" : "Añadir etiqueta",
    "Not found" : "No encontrado",
    "Operator" : "Operador",
    "Actions" : "Acciones",
    "Priority" : "Prioridad",
    "Reset" : "Restablecer",
    "Client ID" : "ID del cliente",
    "Client secret" : "Secreto del cliente",
    "User" : "Usuario",
    "Host" : "Servidor",
    "Port" : "Puerto",
    "Valid until" : "Válido hasta",
    "Certificate" : "Certificado",
    "Submit" : "Enviar",
    "Account connected" : "Cuenta conectada",
    "Connect your mail account" : "Conecte su cuenta de correo",
    "All" : "Todos",
    "Drafts" : "Borradores",
    "Favorites" : "Favoritos",
    "All inboxes" : "Todos los buzones de entrada",
    "Inbox" : "Buzón de entrada",
    "Junk" : "Basura",
    "Sent" : "Enviado",
    "Trash" : "Basura",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Nextcloud Mail" : "Correo de Nextcloud",
    "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
    "Could not load your message" : "No se pudo cargar tu mensaje",
    "Could not load the desired message" : "No se pudo cargar el mensaje deseado",
    "Could not load the message" : "No se pudo cargar el mensaje.",
    "Error loading message" : "Se presentó un error al cargar el mensaje",
    "Forwarding to %s" : "Reenviando a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Haga click aqui si no es redireccionado automáticamente dentro de los siguietes segundos. ",
    "Redirect" : "Redireccionar",
    "The link leads to %s" : "El link lleva a %s",
    "Continue to %s" : "Continuar a %s"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-mail-5.1.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/es_AR.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Importante",
    "Work" : "Trabajo",
    "Personal" : "Personal",
    "Later" : "Después",
    "Mail" : "Correo",
    "Connecting" : "Conectando",
    "Save" : "Guardar",
    "Connect" : "Conectar",
    "Password required" : "Se requiere contraseña",
    "Name" : "Nombre",
    "Mail address" : "Dirección de correo",
    "Password" : "Contraseña",
    "IMAP Host" : "Servidor IMAP",
    "None" : "Ninguno",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Puerto IMAP",
    "IMAP User" : "Usuario IMAP",
    "IMAP Password" : "Contraseña IMAP",
    "SMTP Host" : "Servior SMTP",
    "SMTP Port" : "Puerto SMTP",
    "SMTP User" : "Usuario SMTP",
    "SMTP Password" : "Contraseña SMTP",
    "Aliases" : "Aliases",
    "Signature" : "Firma",
    "Go back" : "Regresar",
    "Change name" : "Cambiar nombre",
    "Cancel" : "Cancelar",
    "Add mail account" : "Agregar cuenta de correo",
    "General" : "General",
    "Sorting" : "Orden",
    "Register" : "Registrar",
    "Keyboard shortcuts" : "Atajos de teclado",
    "Compose new message" : "Redactar nuevo mensaje",
    "Newer message" : "Mensaje mas nuevo",
    "Older message" : "Mensaje anterior",
    "Archive" : "Archivar",
    "Delete" : "Borrar",
    "Search" : "Buscar",
    "Send" : "Enviar",
    "Refresh" : "Recargar",
    "Select account" : "Seleccione la cuenta",
    "Subject" : "Asunto",
    "Add attachment from Files" : "Agregar adjunto desde Archivos",
    "Choose" : "Elige",
    "Choose a file to add as attachment" : "Seleccione el archivo a agregar como adjunto",
    "Confirm" : "Confirmar",
    "Favorite" : "Favorito",
    "Read" : "Leer",
    "Edit tags" : "Editar etiquetas",
    "Back" : "Atrás",
    "All day" : "Todo el día",
    "Description" : "Descripción",
    "Create" : "Crear",
    "Select" : "Seleccionar",
    "Comment" : "Comentario",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "More options" : "Más opciones",
    "Remove" : "Borrar",
    "email" : "correo electrónico",
    "Other" : "Otro",
    "Forward" : "Reenviar",
    "Translate" : "Traducir",
    "Unnamed" : "Sin nombre",
    "Choose a folder to store the attachment in" : "Selecccione la carpeta en la cual almacenar el adjunto",
    "Import into calendar" : "Importar al calendario",
    "Download attachment" : "Descargar adjunto",
    "Save to Files" : "Guardar a Archivos",
    "Save all to Files" : "Guardar todos a Archivos",
    "The images have been blocked to protect your privacy." : "Las imágenes han sido bloqueadas para proteger su privacidad. ",
    "Move" : "Mover",
    "Remove account" : "Eliminar cuenta",
    "Quota" : "Cuota",
    "Saving" : "Guardando",
    "Mark all as read" : "Marcar todos como leídos",
    "Rename" : "Renombrar",
    "Clear cache" : "Limpiar caché",
    "New message" : "Mensaje nuevo",
    "Reply" : "Responder",
    "Retry" : "Reintentar",
    "Message" : "Mensaje",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Add" : "Añadir",
    "Clear" : "Borrar",
    "Close" : "Cerrar",
    "Date" : "Fecha",
    "Tags" : "Etiquetas",
    "Custom" : "Personalizado",
    "Tag already exists" : "La etiqueta ya existe",
    "Add tag" : "Añadir etiqueta",
    "Not found" : "No encontrado",
    "Operator" : "Operador",
    "Actions" : "Acciones",
    "Priority" : "Prioridad",
    "Reset" : "Restablecer",
    "Client ID" : "ID del cliente",
    "Client secret" : "Secreto del cliente",
    "User" : "Usuario",
    "Host" : "Servidor",
    "Port" : "Puerto",
    "Valid until" : "Válido hasta",
    "Certificate" : "Certificado",
    "Submit" : "Enviar",
    "Account connected" : "Cuenta conectada",
    "Connect your mail account" : "Conecte su cuenta de correo",
    "All" : "Todos",
    "Drafts" : "Borradores",
    "Favorites" : "Favoritos",
    "All inboxes" : "Todos los buzones de entrada",
    "Inbox" : "Buzón de entrada",
    "Junk" : "Basura",
    "Sent" : "Enviado",
    "Trash" : "Basura",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Nextcloud Mail" : "Correo de Nextcloud",
    "Could not load {tag}{name}{endtag}" : "No fue posible cargar {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Se presentó un problema al cargar  {tag}{name}{endtag}",
    "Could not load your message" : "No se pudo cargar tu mensaje",
    "Could not load the desired message" : "No se pudo cargar el mensaje deseado",
    "Could not load the message" : "No se pudo cargar el mensaje.",
    "Error loading message" : "Se presentó un error al cargar el mensaje",
    "Forwarding to %s" : "Reenviando a %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Haga click aqui si no es redireccionado automáticamente dentro de los siguietes segundos. ",
    "Redirect" : "Redireccionar",
    "The link leads to %s" : "El link lleva a %s",
    "Continue to %s" : "Continuar a %s",
    "Sending …" : "Enviando ..."
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
